<template>
  <section
    :class="{ ['color' + parcel.shop_color]: true, ['layout' + parcel.shop_style]: true }"
    class="parcel">
    <div class="shop-html">
      <div class="shop-body">
        <section class="wrapper">
          <div v-if="parcel.shop_style == 1">
            <header class="clearfix">
              <div class="inner">
                <div id="yatlogo">
                  <img
                    id="yatlogoimg"
                    :src="logo"
                    width="98"
                    height="81">
                </div>
                <div class="contentwidthcontainer">
                  <div id="shopinfo">
                    <div id="shopname">{{ parcel.name }}</div>
                    <div class="hometxt">
                      <p class="inner">{{ parcel.description }}</p>
                    </div>
                  </div>
                </div>
                <div
                  v-if="parcel.admin"
                  id="menu">
                  <ul
                    id="nav"
                    class="tab-buttons">
                    <router-link
                      :to="{name: 'parcelmain'}"
                      tag="li">
                      <a
                        :class="{selected: (this.$route.name === 'parcelmain')}"
                        class="tab">Home
                      </a>
                    </router-link>
                    <router-link
                      :to="{name: 'parcelorders'}"
                      tag="li">
                      <a
                        id="pickup-orders-tab"
                        :class="{selected: (this.$route.name === 'parcelorders')}"
                        class="tab">Deliveries
                      </a>
                    </router-link>
                    <router-link
                      v-if="notWray"
                      :to="{name: 'parcelaccounting'}"
                      tag="li">
                      <a
                        :class="{selected: (this.$route.name === 'parcelaccounting')}"
                        class="tab">Accounting
                      </a>
                    </router-link>
                    <div class="clear"/>
                  </ul>
                </div>
              </div>
            </header>
            <div class="contentwidthcontainer clearfix">
              <div id="sidebar">
                <order-notifications
                  v-if="parcel.admin"
                  :shop="parcel.canonical_name"
                  :show="showOrderNotification" />
                <div id="recent-sales">
                  <h1>Recent Sales</h1>
                  <recent-sales :shop="parcel" />
                </div>
                <headlines />
                <action-buttons
                  :has-swiper="hasSwiper"
                  :shop="parcel" />
              </div>
              <div id="maincontent">
                <router-view
                  :shop="parcel"
                  :orders="orders"
                  @simple-one="simpleOne"
                  @simple-two="simpleTwo"
                  @busy-one="busyOne"
                  @busy-two="busyTwo"
                  @order-changed="getOrders" />
              </div>
            </div>
          </div>
          <div v-if="parcel.shop_style == 2">
            <header class="clearfix">
              <div
                v-if="parcel.admin"
                id="menu">
                <ul
                  id="nav"
                  class="tab-buttons">
                  <router-link
                    :to="{name: 'parcelmain'}"
                    tag="li">
                    <a
                      :class="{selected: (this.$route.name === 'parcelmain')}"
                      class="tab">Home
                    </a>
                  </router-link>
                  <router-link
                    :to="{name: 'parcelorders'}"
                    tag="li">
                    <a
                      id="pickup-orders-tab"
                      :class="{selected: (this.$route.name === 'parcelorders')}"
                      class="tab">Deliveries
                    </a>
                  </router-link>
                  <router-link
                    v-if="notWray"
                    :to="{name: 'parcelaccounting'}"
                    tag="li">
                    <a
                      :class="{selected: (this.$route.name === 'parcelaccounting')}"
                      class="tab">Accounting
                    </a>
                  </router-link>
                  <div class="clear"/>
                </ul>
              </div>
              <div id="yatlogo">
                <img
                  id="yatlogoimg"
                  :src="logo"
                  width="98"
                  height="81">
              </div>
            </header>
            <div class="contentwidthcontainer clearfix contentback">
              <div class="topitems">
                <div class="stamp"/>
                <div class="stamps2"/>
                <div id="shopname">
                  <div class="shoptxt">{{ parcel.name }}</div>
                </div>
                <div class="hometxt">
                  <p>{{ parcel.description }}</p>
                </div>
                <div class="pen"/>
              </div>
              <div id="sidebar">
                <order-notifications
                  v-if="parcel.admin"
                  :shop="parcel.canonical_name"
                  :show="showOrderNotification"
                  :is-shipper="parcel.isShipper" />
                <div id="recent-sales">
                  <h1>Recent Sales</h1>
                  <recent-sales :shop="parcel" />
                </div>
                <headlines />
                <action-buttons
                  :has-swiper="hasSwiper"
                  :shop="parcel" />
              </div>
              <div id="maincontent">
                <router-view
                  :shop="parcel"
                  :orders="orders"
                  @simple-one="simpleOne"
                  @simple-two="simpleTwo"
                  @busy-one="busyOne"
                  @busy-two="busyTwo"
                  @order-changed="getOrders" />
              </div>
            </div>
          </div>
        </section>
      </div>
    </div>
  </section>
</template>

<script>
import ShopBaseView from "../shopBase.js";
import Headlines from "../Headlines.vue";
import ActionButtons from "../ActionButtons.vue";
import OrderNotifications from "../../../../shared/views/shopTransactions/OrderNotification.vue";
import RecentSales from "../RecentSales.vue";

export default {
  components: {
    Headlines,
    ActionButtons,
    OrderNotifications,
    RecentSales
  },
  extends: ShopBaseView,
  data() {
    return {
      notWray: true,
      logo: app.network.data.shop_logo,
      parcel: {},
      hasSwiper: app.computerSettings.swiper,
      orders: [],
      intervalID: "",
      showOrderNotification: false,
      // this tracks when to show a notification
      orderAmount: null
    };
  },
  watch: {
    // this is to handle notifications that could come in while on the order view, and to dismiss the view
    "$route" (to, from) {
      if(to.name === "parcelorders"){
        this.showOrderNotification = false;
      }
      if(from.name === "parcelorders"){
        this.orderAmount = this.orders.length;
      }
    }
  },
  created: function () {
    let self = this;
    this.getData();
    this.getOrders();
    this.intervalID = setInterval( function(){
      self.getOrders();
    }, 10000);
  },
  beforeDestroy: function () {
    clearInterval(this.intervalID);
  },
  methods: {
    getData() {
      app.session.SetSession()
        .then( () => {
        app.api.Get( "/parcel/" + app.session.data.id )
          .then( Response => {
            console.log(Response);
            this.parcel = Response;
            app.Message( "Successfully loaded the Parcel Shop!", "success" );
          })
          .catch( x => app.Message( x.error, "error" ) );
        });
      this.$router.push({name: "parcelmain"});
    },
    simpleOne() {
      this.parcel.shop_style = 1;
      this.parcel.shop_color = 1;
    },
    simpleTwo() {
      this.parcel.shop_style = 1;
      this.parcel.shop_color = 2;
    },
    busyOne() {
      this.parcel.shop_style = 2;
      this.parcel.shop_color = 1;
    },
    busyTwo() {
      this.parcel.shop_style = 2;
      this.parcel.shop_color = 2;
    },
    getOrders(){
      app.api.Get( "/orders/bystatus/?status=completed,delivered")
        .then( Response => {
          this.orders = Response;
          // this is to handle the initial showing of the order notification, and handle updates
          if(this.orderAmount === null){
            this.orderAmount = this.orders.length;
          }
          if(this.$route.name !== "parcelorders"){
            if(this.orders.length > this.orderAmount){
              this.orderAmount = this.orders.length;
              this.showOrderNotification = true;
            }
          }
        })
      .catch( x => app.Message( x.error, "error" ) );
    }
  },
};
</script>

<style lang="less">
.parcel.layout1.color1 {
  .clearfix:after { content: "."; display: block; height: 0; clear: both; visibility: hidden; }
  .clearfix { display: inline-block; }
  * .shop-html .clearfix { height: 1%; }
  .clearfix { display: block; }

  /* Parcel common */

  @sidebarcolor: none;
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: left;
  @maincontentfloat:right;
  @bgimage: url(/images/shop/parcel/townhall2bigbg.jpg);
  @bgimage2: url(/images/shop/parcel/townhall2bigbg.jpg);
  @bgcolor: #b2b2b0;
  @contentborder: 1px solid #ecf4f8;
  @textshadow: #2a6b8f;
  @textshadow2: #d7d7d7;
  @maincontentcolor: #131736;

  .bodyback() {
    background-image: ;
    background-repeat:no-repeat;
    background-position:center 0;
  }
  // Parcel color 1
  @shoptitlecolor: #da802d;
  @shoptitleshadow: -.1rem -.1rem .1rem rgba(0,0,0,.3);
  @shopinfowidth: 61.5rem;
  @logoborder: 0.5rem solid #da802d;
  @shopdesccolor:#227eb1;
  @homemsgcolor:#144a68;
  @bgheader: url(/images/shop/parcel/parcel-bg-header-1.jpg);
  @navdivbg: linear-gradient(to bottom, #4b86b2 0%,#366080 100%);
  @activetabcolor: #fff;
  @navbgcolor: #b2f7be;
  @tabfontcolor: #da802d;
  @hometxtcolor: white;
  @hometxtshadow: -.1rem -.1rem 0 rgba(0,0,0,.4);
  @salesbgtop: url(/images/shop/parcel/bg-sales-top-brown.png);
  @salesbgmiddle: url(/images/shop/parcel/bg-sales-middle-brown.png);
  @salesbgbottom: url(/images/shop/parcel/bg-sales-bottom-brown.png);
  @salesh1color: #592626;
  @salesh2color: white;
  @saleslicolor: #eee;

  @import '../../shared.less';
  @import './parcelLayout1.less';

}

</style>

<style lang="less">
.parcel.layout1.color2 {
  .clearfix:after { content: "."; display: block; height: 0; clear: both; visibility: hidden; }
  .clearfix { display: inline-block; }
  * .shop-html .clearfix { height: 1%; }
  .clearfix { display: block; }

  /* Parcel common */

  @sidebarcolor: none;
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: left;
  @maincontentfloat:right;
  @bgimage: url(/images/shop/parcel/townhall2bigbg.jpg);
  @bgimage2: url(/images/shop/parcel/townhall2bigbg.jpg);
  @bgcolor: #b2b2b0;
  @contentborder: 1px solid #ecf4f8;
  @textshadow: #2a6b8f;
  @textshadow2: #d7d7d7;
  @maincontentcolor: #131736;

  .bodyback() {
    background-image: @bgimage2;
    background-repeat:no-repeat;
    background-position:center 0;
  }
  // Parcel color 2
  @shoptitlecolor: #711fa6;
  @shoptitleshadow: none;
  @shopinfowidth: 61.5rem;
  @logoborder: 0.5rem solid #711fa6;
  @shopdesccolor:#227eb1;
  @homemsgcolor:#144a68;
  @bgheader: url(/images/shop/parcel/parcel-bg-header-2.jpg);
  @navdivbg: linear-gradient(to bottom, #4b86b2 0%,#366080 100%);
  @activetabcolor: #fff;
  @navbgcolor: #b2f7be;
  @tabfontcolor: #00ce00;
  @hometxtcolor: #00ce00;
  @hometxtshadow: none;
  @salesbgtop: url(/images/shop/parcel/bg-sales-top-white.png);
  @salesbgmiddle: url(/images/shop/parcel/bg-sales-middle-white.png);
  @salesbgbottom: url(/images/shop/parcel/bg-sales-bottom-white.png);
  @salesh1color: #711fa6;
  @salesh2color: #4e1673;
  @saleslicolor: #7f6196;

  @import '../../shared.less';
  @import './parcelLayout1.less';


}
</style>

<style lang="less">
.parcel.layout2.color1 {
  // @import url('http://fonts.googleapis.com/css?family=Patrick+Hand');
  // @import url('http://fonts.googleapis.com/css?family=Satisfy');
  .clearfix:after { content: "."; display: block; height: 0; clear: both; visibility: hidden; }
  .clearfix { display: inline-block; }
  * html .clearfix { height: 1%; }
  .clearfix { display: block; }

  /* Parcel common */

  @sidebarcolor: none;
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: left;
  @maincontentfloat:right;
  @bgimage2: url(/images/shop/parcel/townhall2bigbg.jpg);
  @bgcolor: #b2b2b0;
  @contentborder: 1px solid #ecf4f8;
  @textshadow: #2a6b8f;
  @textshadow2: #d7d7d7;
  @maincontentcolor: #131736;

  .bodyback() { background-image:@bgimage ; background-repeat:no-repeat; background-position:center 0; background-color:@bodybgcolor; }
  // Parcel color 1
  @shoptitlecolor: #2f2f2f;
  @shoptitleshadow: -.1rem -.1rem .1rem rgba(0,0,0,.3);
  @shopinfowidth: 61.5rem;
  @logoborder: 0.5rem solid #5496bb;
  @shopdesccolor:#227eb1;
  @homemsgcolor:#144a68;
  @bgheader: url(/images/shop/parcel/parcel-bg-header-1.jpg);
  @navdivbg: linear-gradient(to bottom, #4b86b2 0%,#366080 100%);
  @activetabcolor: #1a2f3b;
  @navbgcolor: #b2f7be;
  @tabfontcolor: #fff;
  @hometxtcolor: #2f2f2f;
  @hometxtshadow: -.1rem -.1rem 0 rgba(0,0,0,.4);
  @salesbgtop: url(/images/shop/parcel/bg-sales-top-brown.png);
  @salesbgmiddle: url(/images/shop/parcel/bg-sales-middle-brown.png);
  @salesbgbottom: url(/images/shop/parcel/bg-sales-bottom-brown.png);
  @salesh1color: #2f2f2f;
  @salesh2color:#2f2f2f;
  @saleslicolor: #787878;
  @bgimage: url('/images/shop/parcel/parcel2bodybg.jpg');
  @maincontentback: url('/images/shop/parcel/parcel-content-back1.jpg');
  @bodybgcolor:#404040;
  @tabh1color: #2f2f2f;
  @contentbackcolor:#e9ba72;

  @import '../../shared.less';
  @import './parcelLayout2.less';


}
</style>

<style lang="less">
.parcel.layout2.color2 {
  .clearfix:after { content: "."; display: block; height: 0; clear: both; visibility: hidden; }
  .clearfix { display: inline-block; }
  * html .clearfix { height: 1%; }
  .clearfix { display: block; }

  /* Parcel common */

  @sidebarcolor: none;
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: left;
  @maincontentfloat:right;
  @bgimage2: url(/images/shop/parcel/townhall2bigbg.jpg);
  @bgcolor: #b2b2b0;
  @contentborder: 1px solid #ecf4f8;
  @textshadow: #2a6b8f;
  @textshadow2: #d7d7d7;
  @maincontentcolor: #131736;

  .bodyback() { background-image:@bgimage ; background-repeat:no-repeat; background-position:center 0; background-color:@bodybgcolor; }
  // Parcel color 2
  @shoptitlecolor: #2f2f2f;
  @shoptitleshadow: none;
  @shopinfowidth: 61.5rem;
  @logoborder: 0.5rem solid #5496bb;
  @shopdesccolor:#227eb1;
  @homemsgcolor:#144a68;
  @bgheader: url(/images/shop/parcel/parcel-bg-header-2.jpg);
  @navdivbg: linear-gradient(to bottom, #4b86b2 0%,#366080 100%);
  @activetabcolor: #1a2f3b;
  @navbgcolor: #b2f7be;
  @tabfontcolor: #1a2f3b;
  @hometxtcolor: #00ce00;
  @hometxtshadow: none;
  @salesbgtop: url(/images/shop/parcel/bg-sales-top-white.png);
  @salesbgmiddle: url(/images/shop/parcel/bg-sales-middle-white.png);
  @salesbgbottom: url(/images/shop/parcel/bg-sales-bottom-white.png);
  @salesh1color: #2f2f2f;
  @salesh2color: #2f2f2f;
  @saleslicolor: #787878;
  @bgimage: url('/images/shop/parcel/parcel2bodybg2.jpg');
  @maincontentback: url('/images/shop/parcel/parcel-content-back2.jpg');
  @bodybgcolor:#dbdbdb;
  @tabh1color: #fff;
  @contentbackcolor:#594222;

  @import '../../shared.less';
  @import './parcelLayout2.less';
}
</style>


